@@ -5,7 +5,6 @@ from __future__ import annotations as _annotations
 import dataclasses
 import warnings
 from collections.abc import Mapping
-from copy import copy
 from functools import cache
 from inspect import Parameter, ismethoddescriptor, signature
 from re import Pattern
@@ -348,7 +347,7 @@ def collect_model_fields(  # noqa: C901
             else:
                 # The field was present on one of the (possibly multiple) base classes
                 # copy the field to make sure typevar substitutions don't cause issues with the base classes
-                field_info = copy(parent_fields_lookup[ann_name])
+                field_info = parent_fields_lookup[ann_name]._copy()
 
         else:  # An assigned value is present (either the default value, or a `Field()` function)
             if isinstance(assigned_value, FieldInfo_) and ismethoddescriptor(assigned_value.default):
